/*
  ==============================================================================

    This file contains the basic framework code for a JUCE plugin editor.

  ==============================================================================
*/

#include "PluginProcessor.h"
#include "PluginEditor.h"

//==============================================================================
PluginWithWindowAudioProcessorEditor::PluginWithWindowAudioProcessorEditor (PluginWithWindowAudioProcessor& p)
    : AudioProcessorEditor (&p), audioProcessor (p)
{
    addAndMakeVisible(openWindow2Button);
    openWindow2Button.onClick = [this] { openWindow2(); };

    // Make sure that before the constructor has finished, you've set the
    // editor's size to whatever you need it to be.
    setSize (400, 300);
}

PluginWithWindowAudioProcessorEditor::~PluginWithWindowAudioProcessorEditor()
{
}

//==============================================================================
void PluginWithWindowAudioProcessorEditor::paint (juce::Graphics& g)
{
    // (Our component is opaque, so we must completely fill the background with a solid colour)
    g.fillAll (getLookAndFeel().findColour (juce::ResizableWindow::backgroundColourId));

    g.setColour (juce::Colours::white);
    g.setFont (15.0f);
    g.drawFittedText ("Hello World!", getLocalBounds(), juce::Justification::centred, 1);
}

void PluginWithWindowAudioProcessorEditor::resized()
{
    // This is generally where you'll want to lay out the positions of any
    // subcomponents in your editor..
    openWindow2Button.setBounds(getLocalBounds().reduced(20).removeFromTop(40));
}

void PluginWithWindowAudioProcessorEditor::openWindow2()
{
    if (!window2)
    {
        window2.reset(new Window2(*this,
                                  new Window2Component(*this),
                                  "Window 2",
                                  Desktop::getInstance().getDefaultLookAndFeel().
                                  findColour(ResizableWindow::backgroundColourId),
                                  DocumentWindow::allButtons));
    }
    window2->setVisible(true);
}


void PluginWithWindowAudioProcessorEditor::closeWindow2()
{
    window2.reset(nullptr);
}

//==============================================================================

Window2Component::Window2Component(PluginWithWindowAudioProcessorEditor& mainRef)
: mainComponent(mainRef)
{
    setSize(300, 400);
}

void Window2Component::paint(Graphics& g)
{
    g.fillAll(getLookAndFeel().findColour(ResizableWindow::backgroundColourId));   // clear the background
}

void Window2Component::resized()
{
}

Window2::Window2(PluginWithWindowAudioProcessorEditor& mainRef, Window2Component *c, const String& name, Colour backgroundColour, int buttonsNeeded)
: DocumentWindow(name, backgroundColour, buttonsNeeded)
, mainComponent(mainRef)
{
    setResizable(true, false);
    setUsingNativeTitleBar(true);
    
    // Let the child determine the size, and just define top-left window position here
    setContentOwned(c, true);
    setTopLeftPosition(100, 100);
}

void Window2::closeButtonPressed()
{
    mainComponent.closeWindow2();
}



