/*
  ==============================================================================

    This file contains the basic framework code for a JUCE plugin editor.

  ==============================================================================
*/

#pragma once

#include <JuceHeader.h>
#include "PluginProcessor.h"
class PluginWithWindowAudioProcessorEditor;

//==============================================================================
/**
*/

class Window2Component    : public Component
{
public:
    Window2Component(PluginWithWindowAudioProcessorEditor& mainRef);
    
    void paint(Graphics& g) override;
    void resized() override;
    
private:
    PluginWithWindowAudioProcessorEditor& mainComponent;
    
    JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (Window2Component)
};

class Window2   : public DocumentWindow
{
public:
    Window2(PluginWithWindowAudioProcessorEditor& mainRef, Window2Component *c, const String& name, Colour backgroundColour, int buttonsNeeded);
    
    void closeButtonPressed() override;
    
    PluginWithWindowAudioProcessorEditor& getMainComponent() { return mainComponent; };
private:
    PluginWithWindowAudioProcessorEditor& mainComponent;
    
    JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (Window2)
};

//==============================================================================

class PluginWithWindowAudioProcessorEditor  : public AudioProcessorEditor
{
public:
    PluginWithWindowAudioProcessorEditor (PluginWithWindowAudioProcessor&);
    ~PluginWithWindowAudioProcessorEditor() override;

    //==============================================================================
    void paint (Graphics&) override;
    void resized() override;

    void closeWindow2();
    void openWindow2();

private:
    TextButton openWindow2Button   { "Open Window 2" };
    std::unique_ptr<Window2> window2;

    // This reference is provided as a quick way for your editor to
    // access the processor object that created it.
    PluginWithWindowAudioProcessor& audioProcessor;

    JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (PluginWithWindowAudioProcessorEditor)
};

